<?php

namespace Vaptreporting\Importreport\Policies;

use Litepie\User\Contracts\UserPolicy;
use Vaptreporting\Importreport\Models\Info;

class InfoPolicy
{

    /**
     * Determine if the given user can view the info.
     *
     * @param UserPolicy $user
     * @param Info $info
     *
     * @return bool
     */
    public function view(UserPolicy $user, Info $info)
    {
        if ($user->canDo('importreport.info.view') && $user->isAdmin()) {
            return true;
        }

        return $info->user_id == user_id() && $info->user_type == user_type();
    }

    /**
     * Determine if the given user can create a info.
     *
     * @param UserPolicy $user
     * @param Info $info
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('importreport.info.create');
    }

    /**
     * Determine if the given user can update the given info.
     *
     * @param UserPolicy $user
     * @param Info $info
     *
     * @return bool
     */
    public function update(UserPolicy $user, Info $info)
    {
        if ($user->canDo('importreport.info.edit') && $user->isAdmin()) {
            return true;
        }

        return $info->user_id == user_id() && $info->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given info.
     *
     * @param UserPolicy $user
     * @param Info $info
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Info $info)
    {
        return $info->user_id == user_id() && $info->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given info.
     *
     * @param UserPolicy $user
     * @param Info $info
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Info $info)
    {
        if ($user->canDo('importreport.info.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given info.
     *
     * @param UserPolicy $user
     * @param Info $info
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Info $info)
    {
        if ($user->canDo('importreport.info.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
