<?php

namespace Vaptreporting\Importreport\Policies;

use Litepie\User\Contracts\UserPolicy;
use Vaptreporting\Importreport\Models\Testtable;

class TesttablePolicy
{

    /**
     * Determine if the given user can view the testtable.
     *
     * @param UserPolicy $user
     * @param Testtable $testtable
     *
     * @return bool
     */
    public function view(UserPolicy $user, Testtable $testtable)
    {
        if ($user->canDo('importreport.testtable.view') && $user->isAdmin()) {
            return true;
        }

        return $testtable->user_id == user_id() && $testtable->user_type == user_type();
    }

    /**
     * Determine if the given user can create a testtable.
     *
     * @param UserPolicy $user
     * @param Testtable $testtable
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('importreport.testtable.create');
    }

    /**
     * Determine if the given user can update the given testtable.
     *
     * @param UserPolicy $user
     * @param Testtable $testtable
     *
     * @return bool
     */
    public function update(UserPolicy $user, Testtable $testtable)
    {
        if ($user->canDo('importreport.testtable.edit') && $user->isAdmin()) {
            return true;
        }

        return $testtable->user_id == user_id() && $testtable->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given testtable.
     *
     * @param UserPolicy $user
     * @param Testtable $testtable
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Testtable $testtable)
    {
        return $testtable->user_id == user_id() && $testtable->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given testtable.
     *
     * @param UserPolicy $user
     * @param Testtable $testtable
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Testtable $testtable)
    {
        if ($user->canDo('importreport.testtable.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given testtable.
     *
     * @param UserPolicy $user
     * @param Testtable $testtable
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Testtable $testtable)
    {
        if ($user->canDo('importreport.testtable.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
