<?php

namespace Vaptreporting\Importreport\Providers;

use Illuminate\Support\ServiceProvider;

class ImportreportServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'importreport');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'importreport');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('vaptreporting.importreport', function ($app) {
            return $this->app->make('Vaptreporting\Importreport\Importreport');
        });

        // Bind Testtable to repository
        $this->app->bind(
            'Vaptreporting\Importreport\Interfaces\TesttableRepositoryInterface',
            \Vaptreporting\Importreport\Repositories\Eloquent\TesttableRepository::class
        );
        // Bind Info to repository
        $this->app->bind(
            'Vaptreporting\Importreport\Interfaces\InfoRepositoryInterface',
            \Vaptreporting\Importreport\Repositories\Eloquent\InfoRepository::class
        );

        $this->app->register(\Vaptreporting\Importreport\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Vaptreporting\Importreport\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['vaptreporting.importreport'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('vaptreporting/importreport.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/importreport')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/importreport')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
